#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in 

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "N'exécutez pas le script app_upgrade directement. Pour mettre à niveau une application, exécutez l'une des commandes suivantes : "
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Entrez -help pour afficher la description complète des commandes ci-dessus."
;;

INVALID_START_DIR )
echo ""
echo "Sauf si vous utilisez le paramètre -help, vous ne pouvez pas exécuter le script $2 à partir d'un répertoire autre que $3 "
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "Le fichier '$2' contient les valeurs de paramètre pour le script de mise à niveau. "
echo "Pour modifier ces valeurs de paramètre par défaut, éditez ces fichiers ou spécifiez les valeurs de paramètre sous forme d'arguments de ligne de commande pour les scripts de mise à niveau. "
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "L'ensemble de fichiers suivant contient des valeurs de paramètre par défaut pour une mise à niveau d'application. Pour modifier ces valeurs de paramètre par défaut, éditez ces fichiers ou spécifiez les valeurs de paramètre sous forme d'arguments de ligne de commande pour les scripts de mise à niveau. "
echo "- DM upgrade :   $2/params/dm_params$3.sh"
echo "- VVC upgrade :  $2/params/vvc_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "Aucun type d'application n'a été indiqué. Pour mettre à niveau une application, exécutez l'une des commandes suivantes : "
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Entrez -help pour afficher la description complète des commandes ci-dessus."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 n'est pas un type d'application valide. Pour mettre à niveau une application, exécutez l'une des commandes suivantes : "
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Entrez -help pour afficher la description complète des commandes ci-dessus."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Valeur manquante pour le paramètre $2."
echo "Entrez -help pour afficher la description complète des paramètres."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "Le répertoire $3, spécifié pour le paramètre $2, n'existe pas ou n'est pas valide."
echo "Entrez -help pour afficher la description complète des paramètres."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "Le répertoire $3 spécifié pour le paramètre $2 doit être un chemin d'accès absolu."
echo "Entrez -help pour afficher la description complète des paramètres."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "Le fichier $3, spécifié pour le paramètre $2, n'existe pas ou n'est pas valide."
echo "Entrez -help pour afficher la description complète des paramètres."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 est une valeur non admise pour le paramètre $2. "
echo "Entrez -help pour afficher la description complète des paramètres."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 est un paramètre inconnu."
echo "Entrez -help pour afficher la description complète des paramètres."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Paramètre de répertoire principal $2 manquant."
echo "Entrez -help pour afficher la description complète des paramètres."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "Le répertoire $2 n'existe pas ou n'est pas valide."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "La commande repotools de l'application '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -oldApplicationHome '$3' pointe vers l'ancien répertoire de configuration de serveur, par exemple, 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "La commande repotools de l'application '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -oldApplicationHome '$3' pointe vers l'ancien répertoire de configuration de serveur, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "Fichier de configuration '$2' introuvable."
echo ""
echo "Vérifiez que le paramètre -oldApplicationHome '$3' pointe vers l'ancien répertoire de configuration de serveur, par exemple, 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "Fichier de configuration '$2' introuvable."
echo ""
echo "Vérifiez que le paramètre -oldApplicationHome '$3' pointe vers l'ancien répertoire de configuration de serveur, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "La commande repotools de l'application '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -newApplicationHome '$3' pointe vers le nouveau répertoire de configuration de serveur d'applications, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo "Si vous procédez à une mise à niveau à partir d'une édition précédente, vérifiez que vous avez sélectionné les racines de contexte appropriées. Par exemple, si vous utilisez Installation Manager, vous devez sélectionner l'option de racine de contexte $5 sur le panneau "Context Root Options". Si vous avez sélectionné une autre option par inadvertance, vous devez réinstaller le produit avec l'option de racine de contexte $5. "
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "Fichier de configuration '$2' introuvable."
echo ""
echo "Vérifiez que le paramètre -newApplicationHome '$3' pointe vers le nouveau répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo "Si vous procédez à une mise à niveau à partir d'une édition précédente, vérifiez que vous avez sélectionné les racines de contexte appropriées. Par exemple, si vous utilisez Installation Manager, vous devez sélectionner l'option de racine de contexte $5 sur le panneau "Context Root Options". Si vous avez sélectionné une autre option par inadvertance, vous devez réinstaller le produit avec l'option de racine de contexte $5. "
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "La commande repotools JTS '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -oldJTSHome '$3' pointe vers l'ancien répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "Fichier de configuration '$2' introuvable."
echo ""
echo "Vérifiez que le paramètre -oldJTSHome '$3' pointe vers l'ancien répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "La commande repotools JTS '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -newJTSHome '$3' pointe vers le nouveau répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "Fichier de configuration '$2' introuvable."
echo ""
echo "Vérifiez que le paramètre -newJTSHome '$3' pointe vers le nouveau répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Un fichier tar contenant des données 2.x est requis pour la mise à niveau de $2. "
echo "Entrez -help pour afficher la description complète des paramètres."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_dm )
echo ""
echo ""
echo "============================================="
echo "===    Mise à niveau de DM    ==="
echo "============================================="
echo ""
;;

BANNER_vvc )
echo ""
echo ""
echo "============================================"
echo "===    Mise à niveau de VVC    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "La dernière exécution a échoué à l'étape initiale... "
;;

LAST_STEP_FAILED )
echo ""
echo "La dernière exécution a échoué à l'étape $2..."
echo "Voulez-vous redémarrer la mise à niveau à partir de cette étape ou d'une étape précédente ? "
;;

ALREADY_RUN )
echo ""
echo "La mise à niveau a déjà été effectuée et a abouti..."
echo "Voulez-vous en redémarrer une nouvelle à partir d'une étape spécifique ? "
;;

LAST_STEP_PASSED )
echo ""
echo "La dernière exécution a été arrêtée à l'étape $2..."
echo "Voulez-vous redémarrer la mise à niveau à partir de l'étape en cours $3 ou d'une étape précédente ? "
;;

ENTER_NEXT_STEP )
echo ""
echo "Entrez le numéro de l'étape [$2-$3] à partir de laquelle redémarrer la mise à niveau ou appuyez sur [Entrée] pour annuler : "
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' n'est pas un nombre. Entrez un numéro d'étape valide."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' n'est pas un numéro d'étape valide. Entrez un numéro d'étape valide."
;;

MAX_STEP_NUMBER )
echo ""
echo "La dernière étape est l'étape $2 ; par conséquent, vous ne pouvez pas redémarrer la mise à niveau à l'étape $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "L'étape $2 n'a pas encore été exécutée ; par conséquent, vous ne pouvez pas redémarrer la mise à niveau à l'étape $3."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Etape 0 : Suppression des tables"
echo "-------------------"
;;

STEP_0 )
echo "Etape 0 : Mise à jour des fichiers de configuration"
echo "---------------------------"
;;

STEP_1_ADD )
echo "Etape 1 : Ajout de tables"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Etape $2 : Régénération des index de texte"
echo "-----------------------------------------"
;;

JFS_INDICES_STEP )
echo "Etape $2 : Recréation des index de requête et de recherche"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Etape 2 : Mise à niveau du schéma d'entrepôt de données "
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "La mise à niveau de $2 a échoué à l'étape $3. Corrigez le problème et exécutez à nouveau le script à l'étape $3."
echo "" 
;;

OVERALL_MIGRATION_SUCCESS_DM )
echo ""
echo "La mise à niveau de $2 a abouti. Si vous avez également mis à niveau JTS et VVC, vous pouvez à présent démarrer les serveurs dans votre déploiement. "
echo ""
;;

OVERALL_MIGRATION_SUCCESS_VVC )
echo ""
echo "La mise à niveau de $2 a abouti. Si vous avez également mis à niveau JTS et toutes les applications dépendantes (telles que DM), vous pouvez à présent démarrer les serveurs dans votre déploiement. "
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Répertoire : $2"
echo "Commande :"
;;

ENTER_STEP_ACTION )
echo "Entrez [E] pour exécuter cette étape, [S] pour l'ignorer ou appuyez sur [Entrée] pour annuler l'exécution du script :"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' n'est pas une entrée valide ; 'E', 'S' et 'Entrée' seulement sont admis."
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Un éditeur vi va s'ouvrir pour que vous puissiez vérifier le fichier teamserver.properties $2. "
echo "Vérifiez que la racine d'URI public indiquée par la propriété com.ibm.team.repository.server.webapp.url est correcte."
echo "Vérifiez que les propriétés de la base de données sont correctes."
echo "Lorsque vous avez terminé, sauvegardez vos modifications, le cas échéant, puis fermez l'éditeur afin de continuer l'exécution du script."
echo ""
;;

PAUSE )
echo ""
echo "Entrez [C] pour continuer l'exécution ou appuyez sur [Entrée] pour annuler l'exécution du script : "
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' n'est pas une entrée valide ; 'C' ou 'Entrée' seulement sont admis."
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "Echec de la copie des index de texte à partir de '$2' vers '$3'. "
echo "Vérifiez que la propriété com.ibm.team.fulltext.indexLocation "
echo "définie dans le fichier teamserver.properties. "
echo "Copiez manuellement les index de texte vers ce répertoire"
echo "ou exécutez la commande repotools -rebuildTextIndices pour les regénérer."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERREUR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Aucun URI public n'est défini dans"
echo "$3 ; "
echo "par conséquent, la mise à niveau ne peut pas être démarrée."
echo ""
echo "Ce fichier doit comporter un URI public défini comme suit : "
echo "https\://nomhôte.exemple.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propriété d'URI public com.ibm.team.repository.server.webapp.url doit être indiquée dans le fichier teamserver.properties."
echo "Ajoutez la propriété au fichier teamserver.properties de l'ancienne installation et paramétrez sa valeur sur l'URI racine que tous les clients utilisent pour accéder au serveur."
echo "La racine d'URI public est indispensable au bon fonctionnement de votre nouvelle installation. Sans cette propriété, la mise à niveau ne pourra pas aboutir. "
echo "Pour plus d'informations, voir la rubrique 'Planification de vos URI' dans le centre de documentation. "
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERREUR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Tous les URI publics définis dans"
echo "$3"
echo "sont mis en commentaire ; par conséquent, la mise à niveau ne peut pas être démarrée."
echo ""
echo "Ce fichier doit comporter un URI public non commenté défini comme suit : "
echo "https/://nomhôte.exemple.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propriété d'URI public com.ibm.team.repository.server.webapp.url doit être indiquée dans le fichier teamserver.properties."
echo "Ajoutez la propriété au fichier teamserver.properties de l'ancienne installation et paramétrez sa valeur sur l'URI racine que tous les clients utilisent pour accéder au serveur."
echo "La racine d'URI public est indispensable au bon fonctionnement de votre nouvelle installation. Sans cette propriété, la mise à niveau ne pourra pas aboutir. "
echo "Pour plus d'informations, voir la rubrique 'Planification de vos URI' dans le centre de documentation. "
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "La racine de contexte de JTS est paramétrée sur '$2'."
echo "La racine de contexte de l'application est paramétrée sur '$3'."
echo "Les racines de contexte de jts et de l'application ne peuvent pas être identiques."
echo ""
;;

esac

}
