#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in 

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "app_upgrade スクリプトを直接実行しないでください。  アプリケーションをアップグレードするには、以下のコマンドのいずれかを実行してください。"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "これらのコマンドについて詳しくは、-help を使用してください。"
;;

INVALID_START_DIR )
echo ""
echo "-help パラメーターの使用中を除き、$2 スクリプトを $3 以外のディレクトリーから実行することはできません"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "ファイル '$2' には、アップグレード・スクリプトのパラメーター値が含まれています。"
echo "デフォルト・パラメーター値のいずれかを変更する必要がある場合は、これらのファイルを編集するか、アップグレード・スクリプトのコマンド行引数としてそれらのパラメーター値を指定できます。"
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "以下のファイルのセットには、アプリケーション・アップグレード用のデフォルト・パラメーター値が含まれています。  デフォルト・パラメーター値のいずれかを変更する必要がある場合は、これらのファイルを編集するか、アップグレード・スクリプトのコマンド行引数としてそれらのパラメーター値を指定できます。"
echo "- DM アップグレード:   $2/params/dm_params$3.sh"
echo "- VVC アップグレード:  $2/params/vvc_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "アプリケーション・タイプが指定されませんでした。  アプリケーションをアップグレードするには、以下のコマンドのいずれかを実行してください。"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "これらのコマンドについて詳しくは、-help を使用してください。"
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 は有効なアプリケーション・タイプではありません。  アプリケーションをアップグレードするには、以下のコマンドのいずれかを実行してください。"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "これらのコマンドについて詳しくは、-help を使用してください。"
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "パラメーター $2 に値がありません。"
echo "パラメーターについて詳しくは、-help を使用してください。"
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "$2 パラメーターに指定されたディレクトリー $3 は存在しないか、または無効です。"
echo "パラメーターについて詳しくは、-help を使用してください。"
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "$2 パラメーターに指定されたディレクトリー $3 は絶対パスでなければなりません。"
echo "パラメーターについて詳しくは、-help を使用してください。"
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "$2 パラメーターに指定されたファイル $3 は存在しないか、または無効です。"
echo "パラメーターについて詳しくは、-help を使用してください。"
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 は $2 パラメーターには無効な値です。"
echo "パラメーターについて詳しくは、-help を使用してください。"
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 は不明なパラメーターです。"
echo "パラメーターについて詳しくは、-help を使用してください。"
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "ホーム・ディレクトリー・パラメーター $2 がありません。"
echo "パラメーターについて詳しくは、-help を使用してください。"
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "ディレクトリー $2 は存在しないか、または無効です。"
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "アプリケーション repotools コマンド '$2' が見つかりません。"
echo ""
echo "-oldApplicationHome パラメーター '$3' が、古いサーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指していることを確認してください。"
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "アプリケーション repotools コマンド '$2' が見つかりません。"
echo ""
echo "-oldApplicationHome パラメーター '$3' が、古いサーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指しており、jtsContextRoot パラメーター '$4' が正しいことを確認してください。"
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "構成ファイル '$2' が見つかりません。"
echo ""
echo "-oldApplicationHome パラメーター '$3' が、古いサーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指していることを確認してください。"
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "構成ファイル '$2' が見つかりません。"
echo ""
echo "-oldApplicationHome パラメーター '$3' が、古いサーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指しており、jtsContextRoot パラメーター '$4' が正しいことを確認してください。"
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "アプリケーション repotools コマンド '$2' が見つかりません。"
echo ""
echo "-newApplicationHome パラメーター '$3' が、新規アプリケーション・サーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指しており、jtsContextRoot パラメーター '$4' が正しいことを確認してください。"
echo "旧リリースからアップグレードしている場合は、正しいコンテキスト・ルートを選択していることを確認してください。  例えば、Installation Manager を使用している場合は、「コンテキスト・ルート・オプション」パネルで $5 のコンテキスト・ルート・オプションを選択する必要があります。  誤って別のオプションを選択した場合は、$5 のコンテキスト・ルート・オプションを選択して製品を再インストールする必要があります。"
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "構成ファイル '$2' が見つかりません。"
echo ""
echo "-newJTSHome パラメーター '$3' が、新規 JTS サーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指しており、jtsContextRoot パラメーター '$4' が正しいことを確認してください。"
echo "旧リリースからアップグレードしている場合は、正しいコンテキスト・ルートを選択していることを確認してください。  例えば、Installation Manager を使用している場合は、「コンテキスト・ルート・オプション」パネルで $5 のコンテキスト・ルート・オプションを選択する必要があります。  誤って別のオプションを選択した場合は、$5 のコンテキスト・ルート・オプションを選択して製品を再インストールする必要があります。"
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "JTS repotools コマンド '$2' が見つかりません。"
echo ""
echo "-oldJTSHome パラメーター '$3' が、古い JTS サーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指しており、jtsContextRoot パラメーター '$4' が正しいことを確認してください。"
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "構成ファイル '$2' が見つかりません。"
echo ""
echo "-oldJTSHome パラメーター '$3' が、古い JTS サーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指しており、jtsContextRoot パラメーター '$4' が正しいことを確認してください。"
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "JTS repotools コマンド '$2' が見つかりません。"
echo ""
echo "-newJTSHome パラメーター '$3' が、新規 JTS サーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指しており、jtsContextRoot パラメーター '$4' が正しいことを確認してください。"
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "構成ファイル '$2' が見つかりません。"
echo ""
echo "-newJTSHome パラメーター '$3' が、新規 JTS サーバー構成ディレクトリー (例えば 'JazzInstallDir/server/conf') を指しており、jtsContextRoot パラメーター '$4' が正しいことを確認してください。"
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "$2 のアップグレードには 2.x のデータを含む tar ファイルが必要です。"
echo "パラメーターについて詳しくは、-help を使用してください。"
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_dm )
echo ""
echo ""
echo "============================================="
echo "===    DM アップグレード    ==="
echo "============================================="
echo ""
;;

BANNER_vvc )
echo ""
echo ""
echo "============================================"
echo "===    VVC アップグレード    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "最後の実行が初期ステップで失敗しました..."
;;

LAST_STEP_FAILED )
echo ""
echo "最後の実行がステップ $2 で失敗しました..."
echo "このステップまたは前のステップからアップグレードを再開しますか?"
;;

ALREADY_RUN )
echo ""
echo "アップグレードは既に実行され、正常に完了しました..."
echo "特定のステップから新規アップグレードを再度開始しますか?"
;;

LAST_STEP_PASSED )
echo ""
echo "最後の実行がステップ $2 で正常に停止しました..."
echo "現在のステップ $3 または前のステップからアップグレードを再開しますか?"
;;

ENTER_NEXT_STEP )
echo ""
echo "アップグレードを再開するステップの番号 [$2-$3] を入力してください。キャンセルする場合は [Enter] キーを押してください:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' は数値ではありません。 有効なステップ番号を入力してください。"
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' は無効なステップ番号です。 有効なステップ番号を入力してください。"
;;

MAX_STEP_NUMBER )
echo ""
echo "最後のステップはステップ $2 です。したがって、ステップ $3 からアップグレードを再開することはではません。"
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "ステップ $2 がまだ実行されていないので、ステップ $3 からアップグレードを再開することはできません。"
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "ステップ 0: 表の除去"
echo "-------------------"
;;

STEP_0 )
echo "ステップ 0: 構成ファイルの更新"
echo "---------------------------"
;;

STEP_1_ADD )
echo "ステップ 1: 表の追加"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "ステップ $2: テキスト索引の再構築"
echo "----------------------------"
;;

JFS_INDICES_STEP )
echo "ステップ $2: 照会索引および検索索引の再作成"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "ステップ 2: データウェアハウス・スキーマのアップグレード"
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "$2 のアップグレードがステップ $3 で失敗しました。  問題を訂正してから、スクリプトをステップ $3 から再実行してください。"
echo "" 
;;

OVERALL_MIGRATION_SUCCESS_DM )
echo ""
echo "$2 が正常にアップグレードされました。  JTS および VVC もアップグレードした場合は、ご使用のデプロイメント環境のサーバーを開始できます。"
echo ""
;;

OVERALL_MIGRATION_SUCCESS_VVC )
echo ""
echo "$2 が正常にアップグレードされました。  JTS および依存するアプリケーション (DM など) もアップグレードした場合は、ご使用のデプロイメント環境のサーバーを開始できます。"
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "ディレクトリー: $2"
echo "コマンド:"
;;

ENTER_STEP_ACTION )
echo "このステップを実行するには [E] キー、このステップをスキップするには [S] キー、スクリプトの実行をキャンセルするには [Enter] キーを押してください:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' は無効な入力です。許可されているのは 'E'、'S' または 'Enter' のみです"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "vi エディターが開いたら、$2 teamserver.properties ファイルを確認します。"
echo "com.ibm.team.repository.server.webapp.url プロパティーで示されるパブリック URI ルートが正しいことを確認します。"
echo "データベース・プロパティーが正しいことを確認してください。"
echo "完了したら、変更がある場合は保存し、エディターを閉じてスクリプトの実行を続けます。"
echo ""
;;

PAUSE )
echo ""
echo "実行を続行する場合は [C] キー、スクリプトの実行をキャンセルする場合は [Enter] キーを押してください:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' は無効な入力です。許可されているのは 'C' または 'Enter' のみです"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "テキスト索引を '$2' から '$3' にコピーできませんでした。"
echo "com.ibm.team.fulltext.indexLocation プロパティーを確認してください。"
echo "これは teamserver.properties ファイルで定義されています。"
echo "テキスト索引を手動でこのディレクトリーにコピーするか、"
echo "repotools -rebuildTextIndices を実行してテキスト索引を再構築してください。"
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! エラー !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "パブリック URI が以下で定義されていません。"
echo "$3"
echo "このため、アップグレードを開始できません。"
echo ""
echo "このファイルには、以下のように定義された 1 つのパブリック URI が存在する必要があります。"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "パブリック URI プロパティー com.ibm.team.repository.server.webapp.url が、teamserver.properties ファイルに指定されている必要があります。"
echo "このプロパティーを、古いインストール済み環境の teamserver.properties ファイルに追加し、すべてのクライアントがサーバーに到達するために使用する URI ルートになるように値を設定してください。"
echo "パブリック URI ルートは、新規インストール済み環境が正しく機能するために不可欠です。 このプロパティーが指定されない場合はアップグレードが正常に行われません。  "
echo "詳しくは、インフォメーション・センターの『URI の計画』のトピックを参照してください。"
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! エラー !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "以下で定義されているすべてのパブリック URI は"
echo "$3"
echo "コメント化されているため、アップグレードを開始できません。"
echo ""
echo "このファイルには、以下のように定義された 1 つのコメント化されていないパブリック URI が存在する必要があります。"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "パブリック URI プロパティー com.ibm.team.repository.server.webapp.url が、teamserver.properties ファイルに指定されている必要があります。"
echo "このプロパティーを、古いインストール済み環境の teamserver.properties ファイルに追加し、すべてのクライアントがサーバーに到達するために使用する URI ルートになるように値を設定してください。"
echo "パブリック URI ルートは、新規インストール済み環境が正しく機能するために不可欠です。 このプロパティーが指定されない場合はアップグレードが正常に行われません。  "
echo "詳しくは、インフォメーション・センターの『URI の計画』のトピックを参照してください。"
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "JTS のコンテキスト・ルートが '$2' に設定されています。"
echo "アプリケーションのコンテキスト・ルートが '$3' に設定されています。"
echo "jts とアプリケーションのコンテキスト・ルートを同じにすることはできません。"
echo ""
;;

esac

}
